@@ -20,28 +20,34 @@
 #include "articleviewerwebenginepage.h"
 #include <QWebEngineSettings>
 #include <QWebEngineProfile>
+
+#include "akregatorconfig.h"
+
 using namespace Akregator;
 
 ArticleViewerWebEnginePage::ArticleViewerWebEnginePage(QWebEngineProfile *profile, QObject *parent)
     : WebEngineViewer::WebEnginePage(profile, parent)
 {
-    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
-    settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AutoLoadImages, true);
-    settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, false);
-    settings()->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, false);
-    settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, false);
-    settings()->setAttribute(QWebEngineSettings::XSSAuditingEnabled, false);
-    settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, false);
-    settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
+
+    settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::AutoLoadIconsForPage, false);
     settings()->setAttribute(QWebEngineSettings::ErrorPageEnabled, false);
     settings()->setAttribute(QWebEngineSettings::HyperlinkAuditingEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::JavascriptCanAccessClipboard, false);
+    settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, false);
+    settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessFileUrls, false);
+    settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, false);
+    settings()->setAttribute(QWebEngineSettings::LocalStorageEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
     settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
-    settings()->setAttribute(QWebEngineSettings::AutoLoadIconsForPage, false);
-    settings()->setAttribute(QWebEngineSettings::Accelerated2dCanvasEnabled, false);
-    settings()->setAttribute(QWebEngineSettings::WebGLEnabled, false);
+    settings()->setAttribute(QWebEngineSettings::XSSAuditingEnabled, false);
+
     connect(this, &QWebEnginePage::featurePermissionRequested,
             this, &ArticleViewerWebEnginePage::slotFeaturePermissionRequested);
+    connect(this, &QWebEnginePage::loadProgress,
+            this, &ArticleViewerWebEnginePage::onLoadProgress);
 }
 
 ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage()
@@ -51,6 +57,9 @@ ArticleViewerWebEnginePage::~ArticleViewerWebEnginePage()
 bool ArticleViewerWebEnginePage::acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame)
 {
     Q_UNUSED(type);
+    if (url.scheme() == QLatin1String("data")) {
+        return true;
+    }
     if (isMainFrame && type == NavigationTypeLinkClicked) {
         Q_EMIT urlClicked(url);
         return false;
@@ -63,3 +72,10 @@ void ArticleViewerWebEnginePage::slotFeaturePermissionRequested(const QUrl &url,
     //Denied all permissions.
     setFeaturePermission(url, feature, QWebEnginePage::PermissionDeniedByUser);
 }
+
+void ArticleViewerWebEnginePage::onLoadProgress()
+{
+    double newZoom = static_cast<double>(Settings::zoom() / 100.0);
+    if(zoomFactor() != newZoom)
+        setZoomFactor(newZoom);
+}
