@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
@@ -33,7 +33,7 @@ DownloadArticleJob::~DownloadArticleJob()
 {
     if (mAttachmentTemporaryFile) {
         mAttachmentTemporaryFile->removeTempFiles();
-        mAttachmentTemporaryFile = 0;
+        mAttachmentTemporaryFile = nullptr;
     }
 }
 
@@ -42,7 +42,7 @@ void DownloadArticleJob::forceCleanupTemporaryFile()
     if (mAttachmentTemporaryFile) {
         mAttachmentTemporaryFile->forceCleanTempFiles();
         delete mAttachmentTemporaryFile;
-        mAttachmentTemporaryFile = 0;
+        mAttachmentTemporaryFile = nullptr;
     }
 }
 
